@@ -37,6 +37,7 @@ class DocParser:
                  temp_dir="",
                  languages=["est", "eng", "rus"],
                  max_file_size=100,
+                 face_analyzer=False,
                  ignore_digidoc=False):
 
         """
@@ -47,8 +48,9 @@ class DocParser:
         :param: str save_path: Base directory for files to be saved permanently.
         :param: str temp_dir: Base directory for files to be saved temporary.
         :param: [str] languages: Tika OCR languages.
-        :param: int max_file_size: Maximum file size in MBs that will be parsed. 
-        :param: [bool] ignore digidoc: Whether digidoc containers should be ignored.
+        :param: int max_file_size: Maximum file size in MBs that will be parsed.
+        :param: [bool] face_analyzer: Whether face analyzer is used.
+        :param: [bool] ignore_digidoc: Whether digidoc containers should be ignored.
         """
 
         self.save_attachments = save_attachments
@@ -61,12 +63,25 @@ class DocParser:
         self.langs = languages
         self.ignore_digidoc = ignore_digidoc
         self.scanner = DocScanner()
+        self.face_analyzer = self._load_face_analyzer(face_analyzer)
 
         if (self.ignore_digidoc == False):
             if not utils.check_digidoc_exists():
                 raise FileNotFoundError("Digidoc-tool not found. Either set ignore_digidoc=True or install the tool.")
 
 
+    @staticmethod
+    def _load_face_analyzer(face_analyzer_choice):
+        """
+        Loads FaceAnalyzer.
+        """
+        if face_analyzer_choice:
+            from texta_face_analyzer.face_analyzer import FaceAnalyzer
+            return FaceAnalyzer()
+        else:
+            return None
+
+
     def create_temp_dir_for_parse(self):
         """
         Creates temp directory path.
@@ -200,29 +215,23 @@ class DocParser:
             shutil.rmtree(self.temp_dir)
 
 
-    @staticmethod
-    def _parse_file(document, languages, use_face_analyzer=False):
+    def _parse_file(self, document):
         """
         Parses document using TIKA (for everything) and FaceAnalyzer (for images).
         """
         output_document = {}
         tika_options = {
             "headers": {
-                "X-Tika-OCRLanguage": "+".join(languages),
+                "X-Tika-OCRLanguage": "+".join(self.langs),
                 "X-Tika-PDFextractInlineImages": "true"
             }
         }
-
         # extract faces if an image
-        can_face_analyzer = ESImporter.check_face_analyzer_elegibility(ES_URL)
         is_image_file = document["extension"] in Extension.IMAGE_EXTENSIONS
-        if use_face_analyzer and is_image_file and can_face_analyzer:
-            # import here so we won't die on init if analyzer not installed
-            from texta_face_analyzer.face_analyzer import FaceAnalyzer
-            face_vectors = FaceAnalyzer().vectorize_photo(document["path"])
+        if self.face_analyzer and is_image_file:
+            face_vectors = self.face_analyzer.vectorize_photo(document["path"])
             if face_vectors:
                 output_document[FACE_VECTOR_FIELD_NAME] = [{"name": "UNKOWN_FACE", "vector": v} for v in face_vectors]
-
         # extract text using TIKA
         tika_output = parser.from_file(document["path"], requestOptions=tika_options)
         content = tika_output["content"]
@@ -344,7 +353,7 @@ class DocParser:
         return extracted_attachments
 
 
-    def _parse(self, parser_input, file_name=None, save_to_file=True, use_face_analyzer=False):
+    def _parse(self, parser_input, file_name=None, save_to_file=True):
         """
         :param: str parser_input: Base64 string or file path.
         :param: bool save_to_file: As this function is recursive, specifies whether the file
@@ -451,7 +460,7 @@ class DocParser:
                     if (save_to_file):
                         self.save_document(meta)
                     try:
-                        for parsed_document in self._parse_file(meta, languages=self.langs, use_face_analyzer=use_face_analyzer):
+                        for parsed_document in self._parse_file(meta):
                             parsed_document[META_FIELD] = meta.copy()
                             yield parsed_document
                     except:
@@ -470,9 +479,9 @@ class DocParser:
             item[META_FIELD].pop("path")
 
 
-    def parse(self, parser_input, file_name=None, use_face_analyzer=False):
+    def parse(self, parser_input, file_name=None):
         self.temp_dir = self.create_temp_dir_for_parse()
-        generator = self._parse(parser_input, file_name, use_face_analyzer=use_face_analyzer)
+        generator = self._parse(parser_input, file_name)
         for item in generator:
             self._remove_temp_path_ref(item)
             yield item
